==> haskell-tasty-golden-2.3.5-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-golden
version:              2.3.5
visibility:           public
id:                   tasty-golden-2.3.5-2b6o7aF175u2MMTtNPUpzL
key:                  tasty-golden-2.3.5-2b6o7aF175u2MMTtNPUpzL
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/UnkindPartition/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  7741f9b148d1416864f432abb8065c38
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-golden-2.3.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-golden-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-golden
hs-libraries:         HStasty-golden-2.3.5-2b6o7aF175u2MMTtNPUpzL
depends:
    async-2.2.4-CZCW19AQt64j5Nn1VW4P0 base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    directory-1.3.6.2 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.16.1.0-DocEnhf6XB6BINJWUzA2PL
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
    tasty-1.4.2.1-KW4DwlB8z2Z8L2RVVxSEch
    temporary-1.3-9oLjANbJuS55aHDlOYiYL4 text-1.2.5.0
    typed-process-0.2.10.1-1FQqxShrddQAM3v8aelY1H

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.5-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-golden
version:              2.3.5
visibility:           public
id:                   tasty-golden-2.3.5-IVR5PEIbt4MKvpZYalz4ni
key:                  tasty-golden-2.3.5-IVR5PEIbt4MKvpZYalz4ni
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/UnkindPartition/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  c6e71965baa947a420e6d9902aade486
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-golden-2.3.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-golden-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-golden
hs-libraries:         HStasty-golden-2.3.5-IVR5PEIbt4MKvpZYalz4ni
depends:
    async-2.2.4-I2YTB5000Kj32n0kKJ2NSg base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    directory-1.3.6.2 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.16.1.0-BKNPip5PGw2CnbOiekISfW
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
    tasty-1.4.2.3-5Q3D4h6lqeE1Hc7cRlyl02
    temporary-1.3-BT4ClWqhWoW977cAwv1Vum text-1.2.5.0
    typed-process-0.2.10.1-Hc6IiWd9jg3LYxGWho0Ago

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
